pub async fn serve( addr: SocketAddr, health: Health, shutdown: CancellationToken, ) -> Result<()>
Serve the side-server until shutdown is cancelled, binding addr here.
shutdown
addr
Callers that gate readiness on their listeners actually binding should bind up front and use serve_on instead.
serve_on
Returns an error if the listener cannot bind or axum serving fails.
axum