UpdateSource

Trait UpdateSource 

pub trait UpdateSource {
    // Required method
    fn fetch(&self, release: &ReleaseId) -> Result<StagedArtifact, StageError>;
}
Downloads a release to a side location, never the live path.

Required Methods

fn fetch(&self, release: &ReleaseId) -> Result<StagedArtifact, StageError>

Fetch release into a side location and return the staged artifact.

Errors

Returns StageError::Download when the release cannot be fetched or written to its side location.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors